# Insert your code here. 
def helloworld_Kk():
    print("Kk, hello world!")

def multiply(a, b):
    print(a*b)